# coding:utf8


class HelloServiceHandler(object):

    def sayHello(self):
        print('sayHello')
        return 'hello'
